import os


class DjangoSettingsFileError(Exception):
    pass


def setup():
    if "DJANGO_SETTINGS_MODULE" in os.environ:
        raise DjangoSettingsFileError(
            "DJANGO_SETTINGS_MODULE should not be defined, only "
            + "DJANGO_SETTINGS_FILE is obeyed"
        )
    if "DJANGO_SETTINGS_FILE" not in os.environ:
        raise DjangoSettingsFileError("DJANGO_SETTINGS_FILE is not defined")
    os.environ["DJANGO_SETTINGS_MODULE"] = "django_settings_file.settings"



import os
from importlib.util import module_from_spec, spec_from_file_location

# Recipe for importing from path as documented in importlib
spec = spec_from_file_location(
    "django_settings_file.settings_real", os.environ["DJANGO_SETTINGS_FILE"]
)
module = module_from_spec(spec)
spec.loader.exec_module(module)

# Take all the attributes
globals().update(module.__dict__)
